<?php

App::uses('CakeEventListener', 'Event');
App::uses('CustomEmail', 'Lib');

class AccountCreditListener implements CakeEventListener {

	public function implementedEvents() {
		return array(
			'Model.AccountCredit.completed' => 'sendCreditConfirmationEmail',
			'Model.AccountCredit.creditAdded' => 'sendPaymentRequestPaidConfirmationEmail'
		);
	}

/**
 * Send credit confirmation email.
 *
 * @param CakeEvent $Event
 * @return void
 */
	public function sendCreditConfirmationEmail(CakeEvent $Event) {
		$id = $Event->data['id'];

		$data = ClassRegistry::init('BuzzDiaryAccounts.AccountCredit')->find(
			'first',
			array(
				'contain' => array(
					'Account'
				),
				'conditions' => array(
					'AccountCredit.id' => $id
				)
			)
		);

		// Send payment request email
		if (Configure::check('BuzzDiaryAccounts.credit_confirmation_email_id') === true) {
			$Email = ClassRegistry::init('BuzzEmails.Email');

			$email = ClassRegistry::init('BuzzEmails.Email')->generateEmailData(
				(int)Configure::read('BuzzDiaryAccounts.credit_confirmation_email_id'),
				[
					'fullName' => $data['Account']['full_name'],
					'firstName' => $data['Account']['first_name'],
					'lastName' => $data['Account']['last_name'],
					'amount' => CakeNumber::currency($data['AccountCredit']['amount']),
					'salesRef' => $data['AccountCredit']['sales_ref']
				]
			);

			$Email->queueEmail(
				$email['Email']['subject'],
				$email['Email']['content'],
				array($data['Account']['email'] => $data['Account']['full_name']),
				$email['Email']['from']
			);
		}

		return;
	}

/**
 * Send credit confirmation email after credit is added via a payment request.
 *
 * @param CakeEvent $Event
 * @return void
 */
	public function sendPaymentRequestPaidConfirmationEmail(CakeEvent $Event) {
		$id = $Event->data['id'];

		$data = ClassRegistry::init('BuzzDiaryAccounts.AccountCredit')->find(
			'first',
			array(
				'contain' => array(
					'Account',
					'AccountPaymentRequest'
				),
				'conditions' => array(
					'AccountCredit.id' => $id
				)
			)
		);

		$vars = [
			'fullName' => $data['Account']['full_name'],
			'firstName' => $data['Account']['first_name'],
			'lastName' => $data['Account']['last_name'],
			'amount' => CakeNumber::currency($data['AccountCredit']['amount']),
			'salesRef' => $data['AccountCredit']['sales_ref'],
			'payerName' => $data['AccountPaymentRequest']['name'],
			'payerEmail' => $data['AccountPaymentRequest']['email_address'],
			'requestRef' => $data['AccountPaymentRequest']['reference'],
		];

		$Email = ClassRegistry::init('BuzzEmails.Email');

		// Send email to account holder
		if (Configure::check('BuzzDiaryAccounts.third_party_credit_confirmation_email_id') === true) {
			$email = $Email->generateEmailData(
				(int)Configure::read('BuzzDiaryAccounts.third_party_credit_confirmation_email_id'),
				$vars
			);
			$Email->queueEmail(
				$email['Email']['subject'],
				$email['Email']['content'],
				array($data['Account']['email'] => $data['Account']['full_name']),
				$email['Email']['from']
			);
		}

		// Send email to payer
		if (Configure::check('BuzzDiaryAccounts.payment_request_paid_email_id') === true) {
			$email = $Email->generateEmailData(
				(int)Configure::read('BuzzDiaryAccounts.payment_request_paid_email_id'),
				$vars
			);
			$Email->queueEmail(
				$email['Email']['subject'],
				$email['Email']['content'],
				array($data['Account']['email'] => $data['Account']['full_name']),
				$email['Email']['from']
			);
		}

		return;
	}

}
